#
# spec file for package thonny
#
# Copyright (c) 2024 SUSE LLC
# Copyright (c) 2019-2023 Malcolm J Lewis <malcolmlewis@opensuse.org>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define pythons python3
%define desktop_file_name thonny

Name:           thonny
Version:        4.1.4
Release:        1.2
Summary:        Python IDE for beginners
License:        MIT
URL:            https://thonny.org/
Source0:        https://github.com/thonny/%{name}/archive/v%{version}.tar.gz#/thonny-%{version}.tar.gz
BuildRequires:  fdupes
BuildRequires:  hicolor-icon-theme
BuildRequires:  mypy
BuildRequires:  python-rpm-macros
BuildRequires:  python3-Send2Trash
BuildRequires:  python3-astroid
BuildRequires:  python3-asttokens
BuildRequires:  python3-docutils
BuildRequires:  python3-jedi
BuildRequires:  python3-pylint
BuildRequires:  python3-pyserial
BuildRequires:  python3-pytest
BuildRequires:  python3-setuptools
BuildRequires:  python3-tk
BuildRequires:  update-desktop-files
## MANUAL BEGIN
Requires:       mypy
Requires:       python3-Send2Trash
Requires:       python3-astroid
Requires:       python3-asttokens
Requires:       python3-docutils
Requires:       python3-jedi
Requires:       python3-pylint
Requires:       python3-pyserial
Requires:       python3-setuptools
Requires:       python3-tk
Requires:       python3-wheel
## MANUAL END
Requires(post): desktop-file-utils
Requires(postun): desktop-file-utils
Recommends:     %{name}-lang
BuildArch:      noarch

%description
Thonny is a Python IDE meant for learning programming.

%package        lang
Summary:        Translations for Thonny IDE
Requires:       thonny = %{version}
Requires:       python(abi) = %{python3_version}

%description    lang
Provides translations for Thonny IDE

%prep
%setup -q
# Fix rpm runtime dependency rpmlint error replace the shebang in all the scripts with %%{_bindir}/python3
find . -name "*.py" -exec sed -i 's|#!%{_bindir}/env python3|#!%{_bindir}/python3|' {} ";"

%build
export LC_ALL=en_US.utf8
%python_build

%install
export LC_ALL=en_US.utf8
%python_install
# Install desktop file
mkdir -p %{buildroot}%{_datadir}/applications/
cp packaging/linux/org.thonny.Thonny.desktop %{buildroot}%{_datadir}/applications/%{desktop_file_name}.desktop
%suse_update_desktop_file %{desktop_file_name}
# appdata
mkdir -p %{buildroot}%{_datadir}/metainfo
sed -i "s|org.thonny.Thonny|%{desktop_file_name}|g" packaging/linux/org.thonny.Thonny.appdata.xml
cp packaging/linux/org.thonny.Thonny.appdata.xml %{buildroot}%{_datadir}/metainfo/%{desktop_file_name}.appdata.xml
# icons
for size in 16 22 32 48 64 128 192 256; do
  mkdir -p %{buildroot}%{_datadir}/icons/hicolor/${size}x${size}/apps/
  cp packaging/icons/thonny-${size}x${size}.png %{buildroot}%{_datadir}/icons/hicolor/${size}x${size}/apps/thonny.png
done
# find and mark locale files
%python_find_lang thonny
# fdupes
%fdupes %{buildroot}%{python3_sitelib}

%check
# Skip test as requires Display.
pytest_flags=(-k 'not test_locals_marker')
# failed to access /dev/ttyACM0
pytest_flags+=(--ignore misc/mp/threads_test.py)
%pytest "${pytest_flags[@]}"

%post
# update desktop database
%desktop_database_post
%icon_theme_cache_post
exit 0

%postun
%icon_theme_cache_postun
%desktop_database_postun
exit 0

%files
%exclude %{python3_sitelib}/thonny/locale/
%doc CHANGELOG.rst CREDITS.rst
%license LICENSE.txt
%{_bindir}/thonny
%{python3_sitelib}/thonny
%{python3_sitelib}/thonny-%{version}*-info
%{_datadir}/applications/%{desktop_file_name}.desktop
%{_datadir}/metainfo/%{desktop_file_name}.appdata.xml
%{_datadir}/icons/hicolor/*/apps/thonny.png

%files lang -f python3-thonny.lang
%dir %{python3_sitelib}/thonny/locale/
%dir %{python3_sitelib}/thonny/locale/*
%dir %{python3_sitelib}/thonny/locale/*/LC_MESSAGES

%changelog
* Sat May 25 2024 Andrea Manzini <andrea.manzini@suse.com>
- update to 4.1.4
  * Fix regression in MicroPython package installation, #2979
  * Add better error message for externally managed environments, #3009
  * Fix package installation in remote virtual environments
  * Update Raspberry Pi detection
  * Silence "bad-option-value"-s given by Pylint 3
- update to 4.1.3
  * Fix first run crash on macOS (#2860)
  * Fix package upgrade and uninstall in portable variant (#2902)
  * Fix esptool flasher proposing wrong starting address for ESP32-S2 devices, #2920
  * Fix cursor jumping to Shell when program waits for input and the user types opening
    parenthesis in the editor, #2834
  * Add Catalan translation (by Pere)
  * Update German, French, Portuguese and Romanian translations. (See POEditor for contributions)
- update to 4.1.2
  * Avoid repetitive attempts to restart backend after connection gets lost during a Run (#2836)
  * Automatically hide tooltips if window loses focus, #2607
  * Import optional deps with augmented sys.path, fixes problems with importing plug-ins (#2816)
  * Don't leak main site-packages to virtual environment's sys.path, #2867
  * Fix Assistant error with relative imports, #2873
  * Don't attempt to save unchanged editor at run, #2804
  * Fix MicroPython upload errors by more conservative back-end isolation, #2016, #2851, #2864.
    Many thanks to @chechigp for patience and help!
  * Fix MicroPython code completions by fixing packaging of base MicroPython stubs, #2895
  * Fix various completion failures by reverting a jedi hack (67f2c12)
  * Avoid duplicate MicroPython completions when a module is already imported (852308f)
  * Update Persian, Italian, Japanese, Brazilian Portuguese and Chinese translations (see POEditor for contributions)
* Fri Nov 17 2023 malcolmlewis@opensuse.org
- Add python3-wheel to requires for plugin-manager, (boo#1216951).
- Add python3-setuptools to requires as per rpmlint session.
* Wed Aug  9 2023 Dominik George <nik@naturalnet.de>
- Drop CONTRIBUTING.rst (removed from upstream tarball)
- update to 4.1.1
  * Fix warning for the cases where Thonny avoids user module shadowing a library module (#384)
  * Fix installing from local file in ESP flashing dialog (#2811)
  * Use a tilde to separate pre-release versions in the AppData (#2807), by @jwillikers
  * Use bigger initial width in simple mode
  * Big progress with Italian translation, by mapi68, Ribezzz and sailslack
  * Updated Chinese (TW) and English (UK) translations
- update to 4.1.0
  * Fix MicroPython config page regression introduced in 4.1.0b1 (#2724, #2763)
  * Fix remote Python 3 (SSH) connection error (regression introduced in 4.1.0b1)
  * Fix code completion shortcut displayed in macOS menu
  * Add command "Show esptool version" for ESP flasher
  * Don't disconnect for ESP flasher commands which don't touch the device
  * Close tab on middle click (#2767) by @mrexodia
  * Make package manager support new micropython-lib index (#2777)
  * Report macOS version instead of Darwin version in the About box
  * Implement more flexible Raspberry Pi detection
  * Enable thonny to open and save files with zenity 3.91+ (#2786) by @befeleme
  * Make dbus_next dependency optional (#2771)
  * Recognize ESP32 as possible CircuitPython device
  * Add menu indicator for back-end switcher
  * Allow WebREPL for RP2040 backend (experimental)
  * Use correct MicroPython start address (0x0 instead of 0x1000) when flashing ESP32-S3
  * Recognize ESP32 devices by VID 0x303A
  * Don't show irrelevant ports in port selector (e.g. /dev/cu.Bluetooth-Incoming-Port)
  * Allow setting --flash-size in ESP flasher, #2801
  * Rename "Raspberry Pi" initial settings to "Raspberry Pi (simple)"
  * Update several translations
  * Add en_GB translation
  * Attempt to overcome "window was deleted before its visibility changed" error
  * Fix pipkin directory creation in paste mode (e.g. package installation via WebREPL)
  * Upgrade bundled websockets, paramiko, docutils, mypy, Send2Trash, esptool to latest versions
* Sun Jan 22 2023 Dirk Müller <dmueller@suse.com>
- update to 4.0.2:
  * Fix Mypy logging error in the Assistant, #2491 by @kr-g and @solsword
  * Fix AttributeError on save, #2454
  * Add Thonny version as environment value for user programs
  * Make `__file__` contain absolute path
  * Start SSH preparation command with space to avoid adding it to shell
    history
  * Bump pipkin version to 1.0b8 and fix various bugs with MicroPython
    package installation, including not being able to update a package
  * Restore Find/Replace dialog close button and non-dialog behavior
  * Make Find/Replace dialog non-modal again
  * Fix Find/Replace seeding
  * Restore focus after using file dialogs
  * Don't remove stacktrace links after closing the process
  * Never clear shell when Stop/Restart is used for stopping a process
  * Treat .toml, .gitignore and .env as text files
  * Fix expression box glitch (lower frame box remaining visible) when
    debugging on macOS
  * Ignore disk flushing errors in the end of UF2 installation
  * Make port finding in the end of UF2 installation process more robust
  * Don't enable variant and version selection in UF2 dialog before variants
    get downloaded
  * Add Vietnamese translation, by Bui Huy Quang
  * Update several translations
  * Fix the name for Slowenian
  * Update several deps in Thonny + Python bundles (asttokens, mypy, pylint,
    esptool, paramiko)
* Sun Jan  1 2023 Thomas Wagner <wagner-thomas@gmx.at>
- Update to 4.0.1
  * Drop support for Python 3.5, 3.6 and 3.7
  * Require single click for toggling a breakpoint, #2293
  * Clear Shell before starting new process (Run, Debug, Stop/Restart, ...) by default. Can be turned off in Tools => Options => Shell, #1681
  * Rename "Python 3" back-end to "Local Python 3"
  * Don't SetProcessDpiAwareness for user programs anymore. This means for example, that Tkinter and Pygame programs on Windows run as if they were executed with plain Python (ie they may become blurry on modern displays). For clear picture, start your program with import ctypes; ctypes.OleDLL("shcore").SetProcessDpiAwareness(1), #2159
  * Drop support for jedi versions below 0.18.1
  * Add the option for automatically getting completions while typing (Tools => Options => Editor)
  * Selecting a completion with Tab now replaces the name suffix right of the cursor, #1998
  * Turn off requesting completions with Tab in editors by default, #2069
  * Show documentation for the selected completion with another Ctrl-Space or automatically (Tools => Options => Editor)
  * Add "call-tips" -- a box describing the formal parameters of current method call. Invoke manually with Ctrl-Shift-Space or automatically after typing open parentheses (Tools => Options => Editor)
  * Enhance Go-to-definition (Ctrl-click). The name is now underlined while ctrl-hovering over it.
  * Add LEGO® EV3 back-end: "Run => Select interpreter => MicroPython (EV3)"
  * Support CircuitPython with micro:bit, #2251
  * Use pipkin for managing packages on MicroPython and CircuitPython devices. This enables proper listing of packages together with version info and proper uninstallation.
  * Use .local_rtc config parameters instead of (oppositely worded) .utc_clock in MicroPython back-ends, 116aecd
  * Present MicroPython time options (whether to sync time and whether to use local time) in back-end configuration page, #1638
  * Automatically interrupt current process when connecting to bare-metal MicroPython or CircuitPython device. This can be turned off at device's settings page, #2059
  * Don't hide the output when Stop/Restarting MicroPython, #1805
  * Make internal MicroPython errors less intimidating. In several cases the errors are caused by bugs in MicroPython or USB driver and there is no use of showing the stacktrace. User is now directed to restart the device and stacktrace can be checked from the backend.log, #1799
  * Make MicroPython back-end advise Ctrl+C also if only whitespace characters get printed, #1755
  * Allow running MicroPython scripts without soft-rebooting first, #1565, #1716
  * Add generic "MicroPython (RP2040)" back-end in addition to the more specific "MicroPython (Raspberry Pi Pico)", #2151
  * Mention the possibility to reconfigure file types when denying opening remote files in a system app, #2148
  * Refactor MicroPython/CircuitPython flashing dialog, #2344
  * Add separate "Install ..." items to the back-end switcher menu if a device in UF2 bootloader mode is detected, #2387
  * Use "Install MicroPython" instead of "Install firmware", #2364
  * Take OSC commands into account when looking for prompts (relevant for CircuitPython 8), #2349
  * Disable "Run" command when MicroPython device is disconnected
  * Update completion stubs for MicroPython and CircuitPython (from @hlovatt and @adafruit)
  * Make Shell read-only when device is disconnected
  * Fix various problems with managing files on CircuitPython devices
  * Don't assume all CircuitPython boards have RTC, #1760
  * Fix error with evaluating globals() on MicroPython device, #1938
  * Add MicrobitImage inspector for Object inspector
  * Add TODO view (by @kr-g), #2067
  * Add possibility to activate a virtual environment via Files view (by @kr-g), #2381
  * Add new toolbar button which opens the wiki page describing ways to help Ukraine survive the attack from Russia.
  * Allow running content of untitled editors without saving, #778
  * Make stacktrace links to <stdin> and <input> pseudo-files go to the editor containing corresponding source, #778
  * Ask confirmation for adding .py extension when the user saves the file without any extension to MicroPython/CircuitPython device, #2077
  * Don't add the .py extension when the user saves a local file and selects "All files" filter.
  * Add Cut/Copy/Paste to the file browser, #2001 by @kr-g
  * Make editor remember current line when reloading external changes, #2001 by @kr-g
  * Add "Edit => Go to line..." command (Ctrl-G), #2001 by @kr-g
  * Add "Rename" command for the local file browser, #2001 by @kr-g
  * Add nicer Stop-button for higher resolutions, #1445 by @speedy-10
  * Improve icon scaling -- use larger icons when Treeview row height is larger than general.large_icon_rowheight_threshold
  * Use default font in Treeviews (including Files and Variables view). Therefore Treeview's font size is now affected by the scaling factor and is not affected by editor font size.
  * Use isolated mode for launching Thonny. This includes hiding user-site packages from Thonny's GUI process (not from user programs). Plug-ins now get installed under Thonny's data folder, #2038, #1651
  * Allow installing packages for remote CPython backend, #1319
  * Flatten the list of interpreters in the backend-switcher menu (lower-right corner of the main window)
  * Removed previously deprecated "A special virtual environment". Use regular virtual environments instead.
  * Merge "The same interpreter which runs Thonny" and "Alternative Python 3 interpreter or virtual environment" back-ends into "Local Python 3"
  * Back-end switcher now remembers several configurations for remote CPython and MicroPython.
  * Make package manager work for remote Python 3 (SSH)
  * Fix "Seed find/replace with currently-selected text" for Linux, #2356
  * Use "vista" Tk-theme instead of "xpnative" in Windows. Gives nicer combobox, #1663
  * Automatically reload saved files after external modification (with help from @kr-g), #1589, #1455, #1968
  * Support OSC sequences for setting terminal title, #2369
  * Toggle hidden files also via file-browser's context menu, #1039
  * Seed find/replace with currently-selected text, #2356
  * Add coloring for match and case soft keywords, #2358
  * Add Slovenian translation (by cspaier)
  * Add "Assistant" help page explaining the possibility to omit selected Pylint checks, #1978
  * Add command "Run => Visualize current script at Python Tutor", #2242
  * Add options for automatically making uploaded or saved shebang scripts executable (includes changing Windows line breaks to Unix ones). See "Editor" and SSH-backends' config pages.
  * Allow back-end plugins to modify sys.path, #2281
  * Warn when environment value is provided with quotes, #2184
  * Let macOS installer know the bundle is able to run in arm64 mode, #2201
  * Add Tamil translation, by Kamala Kannan K and அனிச்பிரபு தி, #2211
  * Add Thai translation, by Tomzt Pimai and Game of
  * Allow assigning Python coloring for Python-like files, #1927
  * Many bug-fixes
* Tue Dec 28 2021 Ben Greiner <code@bnavigator.de>
- Remove unused unmaintained python3-pytest-black test requirement
- Reactivate rudimentary test suite on TW
- Find and mark language files
* Wed Nov 10 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Update to 3.3.14:
  * Fix problems in org.thonny.Thonny.appdata.xml
  * Allow assigning Python coloring for Python-like files, #1927
  * Increase the initial top coordinate of Thonny's main window.
  Fixes problem of Thonny's title bar being hidden by the system
  menubar, #1925
- Changelog from previous releases:
  * Restore syncing to localtime for RPi Pico (fixed regression
  introduced in 3.3.11), #1886
  * Fix installing from requirements.txt in MicroPython, #1879
  * Allow specifying different colors for method and function
  calls, by Jonathan Campbell, #1884
  * Extend editor API for plug-ins (close event and content
  load/save hooks), by Nicolas Despres, #1891
  * Fix technical errors in some translations, by Karolina Surma, #1895
  * Warn when inputting non-ascii chars in MicroPython, #1911
  * Fix installing for all users in Windows installer, #1119
  and #1909. See https://github.com/thonny/thonny/wiki/DeploymentOptions#all-users-vs-current-user-install for more info.
  * Prepare Thonny for Flatpak, by Jordan Williams, #1900 and #1912
  * Update minipip to 0.1b5 in order to skip installing Blinka
  when installing libraries for CircuitPython
  * Update Polish translation
  * Update org.thonny.Thonny.appdata.xml
  * Fix MicroPython management errors when user code shadows
  built-in names, #1856
  * Fix package manager getting frozen when installing packages, #1871
  * Fix problem of MicroPython package manager taking module names
  for distribution names, #1833
  * Fix ugly error in ESP flasher dialog when esptool is not found, #1837
  * Fix Tkinter error when using venv created from bundled Python, #1835
  * Use 0..6 for weekday when synchronizing RTC via machine, #1868
  * Make esptool auto-detect chip type, #1838
  * Fix Unix MicroPython time validation (misdiagnosed time offset)
  * Update dependencies in Thonny+Python bundles
  * Update Spanish, Polish, Chinese (TW) translations
  * Support installing regular pip-compatible packages to MicroPython
  or CircuitPython (so far only upip-compatible packages were supported), #1541
  * Fix "error 403" problems when installing MicroPython packages
  from PyPI, #1822
  * Fix error when Object inspector is open and a MicroPython objec
  t can't be found by id, #1796
  * Reduce memory usage by Thonny's MicroPython helper (store last
  REPL value in global _ instead of storing N last values in a list), #1797, #1798
  * Upgraded several dependencies in binary bundles
  * Fix missing libffi6 error in Linux builds, #767
  * Make confugration dialog larger to fit French strings, by sourceperl, #1694
  * Fix "_prepare_after_soft_reboot" error in Unix MicroPython mode, #1715
  * Support interactive programs with Unix MicroPython, #1725
  * Fix read-only filesystem error for CircuitPython in non-English
  variants of CircuitPython, #1662
  * Fix error on right clicking in local file explorer with Italian
  translation, #1713
  * Fix back-end switcher menu position and theme, #1719, #1720
  * Fix "pop from empty list" error when MicroPython is having
  problems, #1586
  * Fix MYPYPATH / MyPy not working, #1124
  * Highlight unclosed strings even inside unclosed parens, #1770
  * Fix problem running code via WebREPL, #1762
  * Make Outline show also async, defs #1787
  * Don't show full error info when ManagementError doesn't seem to be
  Thonny's fault, #1788
  * Don't show error dialog when querying globals fails (error is
  shown on the variables table instead), #1789
  * Recover from corrupted rpc.sock ("invalid literal for int()
  with base 10" error), #1745
  * Add 3 translated Help files for Spanish, by José Carlos García, #1759
  * Add Korean translations of Help files, by Hyungseok Choi, #1758
  * Add first version of Finnish translation by Lrasinen
  * Update translations for Albanian, French, Korean
  * Add newer MyPy (0.812) to binary bundles
  * Fix crash in Shell when negative int-s are evaluated in
  MicroPython (regression introduced in 3.3.4), #1670
  * Fix problems with wm_overrideredirect on macOS with Tk 8.6.11, #1659
  * Fix crash in Plotter when more than 10 numbers are plotted, #1648
  * Hide unsuitable PYTHONPATH environment variable in macOS, #1651
  * Fix too short reprs at MicroPython REPL (regression introduced in 3.3.4), #1627
  * Fix incorrect presentation of long output lines, #1628
  * Fix error in nicer debugger when stepping in generators, #1631
  * Fix infinite recursion error when evaluating globals() in MicroPython
  REPL while object inspector is open, #1641
  * Update Greek translation
  * CHANGED: MicroPython time synchronization now sets RTC to local
  time instead of UTC. This can be changed via a hidden configuration
  option (https://github.com/thonny/thonny/wiki/MicroPython#advanced-configuration), #1603
  * Add time synchronization for RaspberryPi Pico, #1563, #1592
  * Skip loading obsolete thonny-pico plug-in, which is now built in, #1575
  * Get rid of misleading SSL warning in micropip.py and show a warning
  about non-MicroPython packages, #1621
  * Fix WebREPL connection for MicroPython 1.14 by using regular paste
  mode instead of the new raw-paste mode, #1613
  * Delay importing jedi and asttokens for improved performance, #1556
  * Don't assume "dialout" group is required when MicroPython
  connection fails with permission error, #1286
  * Reduce the memory usage of showing global variables by capping
  object representations to 50 first characters in MicroPython, #1582
  * Add Hungarian translation (by Laszlo Kocsis)
  * Updated translations for German, Korean, Italian, Dutch (by various authors)
* Tue Feb  2 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Drop python singlespec since thonny is an app, not a lib.
- Add desktopfiles support
* Tue Feb  2 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Fix required python module
* Mon Jan 25 2021 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Updated to version 3.3.3:
  * Add MicroPython support for Raspberry Pi Pico
    (https://www.raspberrypi.org/blog/raspberry-pi-silicon-pico-now-on-sale/)
  * Better support for MicroPython daily builds, #1545, #1553
  * Automatically prepend relevant Anaconda directories to PATH.
    Fixes problem with importing Anaconda's numpy, #1522
  * Make custom Python chooser see more interpreters, #1522
  * Fix several spelling mistakes, by freddii, #1534
  * Update toolbar buttons, when another editor gets selected,
    fixes wrong button states, #1536
  * Catch errors when opening file in system app, #1526
  * Fix internal error while using Outline View, #1543
  * Fix truncated System Shell environment on macOS, #1529
  * Add /usr/local/bin to the PATH of the back-end process if missing, #1131
  * Fix error while parsing Pygame Zero error, #1535
  * Fix MicroPython completion errors with jedi 0.18, #1560
  * Add incomplete Korean language by Augene J. Pak, Fabianus.c,
    Suk-Hyung Hwang, YEON, $1531
  * Add incomplete Albanian translation by Algent Albrahimi
  * [Technical] Allow older Send2Trash (Fedora doesn't have version 1.5 of this)
  * [Technical] Remove erroneous executable flags from some files
- Changelog from skipped version 3.3.2:
  * Fix the problem of missing docstrings, #1481
  * Fix MicroPython management error after executing machine.reset(), #1492
  * Add support for MicroPython raw paste mode (usable in MicroPython 1.14+), #1498
  * Restore MicroPython raw mode as fallback, should fix problems with
    M5Stick and W600, #1516
  * Add syntax highlighting for non-decimal number literals and support
    underscores, #1482 by Stefan Rothe
  * Make sure all output from the program gets presented, #1504
  * Interrupt current program when running a MicroPython script, #1512
  * Add support for Jedi 0.18, #1497
  * Fix arguments completions for jedi 0.16+, #1511
  * Make micro:bit support a bit more robust, #1515
  * Add Persian (Farsi) translation by Farshid Meidani
  * Add Slovak translation by jose1711
  * Add Armenian translation by Avag. sayan
  * Update Italian and Chinese (TW) translations
* Thu Dec 24 2020 malcolmlewis@opensuse.org
- Updated to version 3.3.1:
  * Allow installing MicroPython to micro:bit v2.
  * Fix problem with MicroPython programs creating lot of output
    very quickly, (gh#thonny/thonny#1419).
  * Fix wrong message when saving to MP and device is busy,
    (gh#thonny/thonny#1437).
  * Bump Pyserial version from 3.5b1 to 3.5, fix problem with some
    ESP devices, (gh#thonny/thonny#1443).
  * Fix error when trying to download file from microbit,
    (gh#thonny/thonny#1440).
  * Don't assume anything about conf files in Pi theme,
    (gh#thonny/thonny#1436).
  * Fix error on reseting MicroPython device,
    (gh#thonny/thonny#1442).
  * Fix unwanted output from expession statements in MicroPython,
    (gh#thonny/thonny#1441).
  * Treat double-click in the remote file dialog differently from
    double-click in the Files view, (gh#thonny/thonny#1432).
  * Fix error when closing MP file dialog without name,
    (gh#thonny/thonny#1431).
  * Refactor "File => Rename" command (new label "Move / rename"
    and you can't "rename" a file on MP device to a file on local
    disc and vice versa), (gh#thonny/thonny#1446).
  * Fix broken links in help pages, (gh#thonny/thonny#1447).
  * Use THONNY_USER_DIR/temp for temp files. Fixes printing when
    default browser is Snap Chrome, (gh#thonny/thonny#1435).
  * Fix error when clicking on "Attributes" tab on Object Inspector
    when no object is selected (MP) (gh#thonny/thonny#1450).
  * Allow specifying DTR/RTS for serial connection (to avoid
    restarting ESP on connect), (gh#thonny/thonny#1462).
  * Open log window automatically if work dialog encounters error,
    (gh#thonny/thonny#1466).
  * Don't close work dialog automatically if log window is opened,
    (gh#thonny/thonny#1465).
  * Fix dummy MicroPython packages giving ugly errors,
    (gh#thonny/thonny#1464).
  * Fix crashes in Assistant view with Dracula theme,
    (gh#thonny/thonny#1463).
  * Work around Caps lock problem when binding command shortcuts,
    (gh#thonny/thonny#1347).
  * Translation updates.
* Thu Nov 19 2020 malcolmlewis@opensuse.org
- Updated to version 3.3.0:
  * Removed automatic tabs => spaces conversion and its
    confirmation dialog, (gh#thonny/thonny#599).
  * Added command for replacing tabs with spaces,
    (gh#thonny/thonny#1411).
  * Added option for highlighting tabs (Tools => Options =>
    Editor), (gh#thonny/thonny#1409).
  * Added option for indenting with tabs (Tools => Options =>
    Editor), (gh#thonny/thonny#599).
  * Add an option to use Tk file dialogs instead of Zenity in
    Linux, (gh#thonny/thonny#1404).
  * Reduce max repr length for MicroPython (1000 instead of 5000).
  * Forward https_proxy or http_proxy variable to pip,
    (gh#thonny/thonny#535).
  * Allow specifying environment variables for the UI process,
    (gh#thonny/thonny#1421).
  * Remove special support for Friendly-traceback,
    (gh#thonny/thonny#1416).
  * Use exclusive access when connecting to a MP device over a
    serial port, (gh#thonny/thonny#1418).
  * Make sure expression box for while/for test is located
    properly, (gh#thonny/thonny#1134).
  * In MicroPython backends only warn about failed epoch dectection
    if sync or validation is required.
  * Don't show ugly traceback in debug mode.
  * Internal error while debugging exceptions,
    (gh#thonny/thonny#1403).
  * Automatically create Thonny user dir in remote machine,
    (gh#thonny/thonny#1365).
  * Fix MicroPython uploading/downloading when started from an
    expanded dir, (gh#thonny/thonny#1398).
  * Fix unrensponsive UI when MicroPython is printing in infinite
    loop, (gh#thonny/thonny#1419).
  * Fix ugly stacktrace, when MicroPython device is disconnected
    during processing a command, (gh#thonny/thonny#1420).
  * Translation updates and additions.
* Fri Apr  3 2020 malcolmlewis@opensuse.org
- Updated to version 3.2.7:
  * TECHNICAL: Skip name hilighter tests for recent Jedi versions.
* Thu Feb  6 2020 malcolmlewis@opensuse.org
- Update to version 3.2.6:
  * Make highlight names work with recent Jedi versions,
    (gh#thonny/thonny#1035).
  * Can't load files from MicroPython device (regression introduced
    in 3.2.5), (gh#thonny/thonny#1043).
  * Missing "Local files" label on save target selection dialog.
- Changes from version 3.2.5:
  * Python version in binary bundles upgraded from 3.7.5 to 3.7.6.
  * MyPy checks are now enabled by default (Tools => Options =>
    Assistant).
  * New Pylint checks are enabled.
  * Thonny can now display/copy/paste Unicode emojis with Python
    3.7.6+ / 3.8.1+. Selection can be still wonky, Fixed by
    (gh#python/cpython#16545), (gh#thonny/thonny#32).
  * "Open System Shell" fails when no script is open,
    (gh#thonny/thonny#815.
  * Scrollbar in Help and Assistant acts funny,
    (gh#thonny/thonny#973).
  * Crash on startup when Shell gets text inserted too soon,
    (gh#thonny/thonny#1019).
  * Accept code completions without parent and full_name,
    (gh#thonny/thonny#1023).
  * Extra imports by Thonny's back-end make stdlib name shadowing
    more troublesome, (gh#thonny/thonny#1025).
  * Allow '+' in image data URI chars in Shell,
    (gh#thonny/thonny#1026).
  * Thonny now has preliminary support for Friendly Traceback,
    (gh#thonny/thonny#1028).
  * Allow larger images in shell (don't squeeze image URI-s),
    (gh#thonny/thonny#401).
  * Fallback to English, when configured language can't be loaded.
  * Problem using esptool on PATH.
- Changes from version 3.2.4:
  * XXL bundle now includes also pandas.
  * Make faster tracer show exceptions only with step_over and
    step_into.
  * Use traditional stack view by default in Simple mode,
    (gh#thonny/thonny#1018).
  * Improved performance for Faster debugger (proposed and
    supported by Raspberry Pi).
  * Fix stepping through lambdas with faster debugger,
    (gh#thonny/thonny#975).
  * Don't report certain exceptions in faster debugger,
    (gh#thonny/thonny#977).
  * Propose replacing tabs with spaces only in the editor (not in
    debugger frames), (gh#thonny/thonny#983).
  * Nicer debugger fails when run with breakpoints only in
    secondary files, (gh#thonny/thonny#986).
  * MicroPython autocomplete problems by adzierzanowski,
    (gh#thonny/thonny#987).
  * Wrong interpretation of MicroPython file timestamps,
    (gh#thonny/thonny#1003).
  * Avoid testing included MicroPython stubs,
    (gh#thonny/thonny#1005).
  * Translation updates and additions.
* Tue Nov 19 2019 malcolmlewis@opensuse.org
- Initial build at version 3.2.3.
